document.addEventListener('DOMContentLoaded', () => {
    const form = document.getElementById('feedbackForm');
    const ratingButtons = document.querySelectorAll('.rating button');
    const statusMessage = document.getElementById('statusMessage');
    let selectedRating = 0;

    // Rating system
    ratingButtons.forEach(button => {
        button.addEventListener('click', (e) => {
            e.preventDefault();
            selectedRating = parseInt(button.dataset.value);
            
            // Update stars visual
            ratingButtons.forEach(btn => {
                if (parseInt(btn.dataset.value) <= selectedRating) {
                    btn.classList.add('active');
                } else {
                    btn.classList.remove('active');
                }
            });
        });
    });

    // Form submission
    form.addEventListener('submit', async (e) => {
        e.preventDefault();
        
        const formData = {
            name: form.name.value,
            email: form.email.value,
            category: form.category.value,
            message: form.message.value,
            rating: selectedRating
        };

        try {
            // Simulate API call
            await new Promise(resolve => setTimeout(resolve, 1000));
            
            // Show success message
            showStatus('Thank you for your feedback!', 'success');
            form.reset();
            ratingButtons.forEach(btn => btn.classList.remove('active'));
            selectedRating = 0;
            
        } catch (error) {
            showStatus('There was an error submitting your feedback. Please try again.', 'error');
        }
    });

    function showStatus(message, type) {
        statusMessage.textContent = message;
        statusMessage.className = `status-message ${type}`;
        statusMessage.style.display = 'block';
        
        setTimeout(() => {
            statusMessage.style.display = 'none';
        }, 5000);
    }

    // Form field animations
    const formFields = document.querySelectorAll('input, textarea, select');
    formFields.forEach(field => {
        field.addEventListener('focus', () => {
            field.parentElement.classList.add('focused');
        });
        
        field.addEventListener('blur', () => {
            if (!field.value) {
                field.parentElement.classList.remove('focused');
            }
        });
    });
});